//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
// 
// uIOEvent.cc -- 
// 
// Author           : Russell Mok
// Created On       : Fri Dec 12 10:24:56 1997
// Last Modified By : Peter A. Buhr
// Last Modified On : Sat Mar  5 09:18:21 2005
// Update Count     : 102
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 

#define __U_KERNEL__
#include <uC++.h>
#include <uIOEvent.h>
#include <cerrno>


uIOFailure::uIOFailure( const char *const msg ) : uEHM::uDualClass( msg ) {
    uErrno = errno;
} // uIOFailure::uIOFailure

uIOFailure::~uIOFailure() {}

int uIOFailure::errNo() const {
    return uErrno;
} // uIOFailure::errNo


// Local Variables: //
// compile-command: "gmake install" //
// End: //
